==> spring-boot-ext-1.2.102-sources.jar: cn/com/duibaboot/ext/autoconfigure/web/container/UndertowMethodInterceptor.java <==
package cn.com.duibaboot.ext.autoconfigure.web.container;

import cn.com.duiba.wolf.threadpool.MonitorRunnable;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.EnhancedInstance;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.InstanceMethodsAroundInterceptor;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.MethodInterceptResult;

import java.lang.reflect.Method;

/**
 * 改变undertow的org.xnio.XnioWorker$TaskPool内部类的字节码，使得提交的runnable封装成MonitorRunnable后再提交
 */
public class UndertowMethodInterceptor implements InstanceMethodsAroundInterceptor {

    @Override
    public void beforeMethod(EnhancedInstance objInst, Method method, Object[] allArguments,
                             Class<?>[] argumentsTypes, MethodInterceptResult result) throws Throwable {
        if (method.getName().equals("execute") && method.getParameterTypes().length == 1
                && method.getParameterTypes()[0].equals(Runnable.class)) {
            Runnable runnable = (Runnable)allArguments[0];
            //改变参数
            allArguments[0] = new MonitorRunnable(runnable);
        }
    }

    @Override
    public Object afterMethod(EnhancedInstance objInst, Method method, Object[] allArguments,
                              Class<?>[] argumentsTypes, Object ret) throws Throwable {
        return ret;
    }

    @Override
    public void handleMethodException(EnhancedInstance objInst, Method method, Object[] allArguments,
                                      Class<?>[] argumentsTypes, Throwable t) {

    }
}

==> spring-boot-ext-1.2.164-sources.jar: cn/com/duibaboot/ext/autoconfigure/web/container/UndertowMethodInterceptor.java <==
package cn.com.duibaboot.ext.autoconfigure.web.container;

import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.InstanceMethodsAroundInterceptor;
import cn.com.duibaboot.ext.autoconfigure.javaagent.core.interceptor.enhance.MethodInterceptResult;
import cn.com.duibaboot.ext.autoconfigure.threadpool.proxy.MonitorRunnable;

import java.lang.reflect.Method;

/**
 * 改变undertow的org.xnio.XnioWorker$TaskPool内部类的字节码，使得提交的runnable封装成MonitorRunnable后再提交
 */
public class UndertowMethodInterceptor implements InstanceMethodsAroundInterceptor {

    @Override
    public void beforeMethod(Object objInst, Method method, Object[] allArguments,
                             Class<?>[] argumentsTypes, MethodInterceptResult result) throws Throwable {
        if (method.getName().equals("execute") && method.getParameterTypes().length == 1
                && method.getParameterTypes()[0].equals(Runnable.class)) {
            Runnable runnable = (Runnable)allArguments[0];
            //改变参数
            allArguments[0] = new MonitorRunnable(runnable);
        }
    }

    @Override
    public Object afterMethod(Object zuperCall, Object objInst, Method method, Object[] allArguments,
                              Class<?>[] argumentsTypes, Object ret) throws Throwable {
        return ret;
    }

    @Override
    public void handleMethodException(Object objInst, Method method, Object[] allArguments,
                                      Class<?>[] argumentsTypes, Throwable t) {

    }
}
